#!/sbin/sh
#
# NativeSD Restore Script v1.0
# Author: tytung - xda-developers

TYPE=$1
if [ "$TYPE" = "" ]; then
	echo Please specify Restore Type: boot, system or data.
	exit 0
fi

# Get $HOME=/sdcard/NativeSD/Backup
HOME=`cat '/tmp/aroma/backup_home.prop' | sed 's/HOME=//g'`

# Get the chosen ROM NAME
ROM_NAME=`cat '/tmp/aroma/target_rom_name.prop' | sed 's/rom_name=//g'`

# Get the target restore folder name
RESTORE_NAME=`cat '/tmp/aroma/target_restore_name.prop' | sed 's/restore_name=//g'`

# Get the target restore folder path on the SD card
RESTORE_DIR="$HOME/$ROM_NAME/$RESTORE_NAME"

if [ "$TYPE" = "boot" ]; then

	if [ -f "$RESTORE_DIR/$TYPE.vfat.tar" ]; then

		# Enter FAT32 partition
		BOOT_DIR="$HOME/../$ROM_NAME"
		if [ ! -d "$BOOT_DIR" ]; then
			mkdir -p "$BOOT_DIR"
		fi
		cd "$BOOT_DIR"

		# Extract
		tar -xvf "$RESTORE_DIR/$TYPE.vfat.tar"

		# Copy files to SD Boot Dir
		cp -a zImage    ../
		cp -a initrd.gz ../

		echo "status=ok" > "/tmp/aroma/restore_status.prop"

	else

		echo "status=fail" > "/tmp/aroma/restore_status.prop"

	fi

else # system and data

	if [ -f "$RESTORE_DIR/$TYPE.ext4.tar" ]; then

		# Enter SD-EXT partition
		EXT_ROM_DIR="/NativeSD/$ROM_NAME"
		if [ ! -d "$EXT_ROM_DIR" ]; then
			mkdir -p "$EXT_ROM_DIR"
		fi
		cd "$EXT_ROM_DIR"

		# Remove the whole system or data folder
		rm -rf "$TYPE"

		# Extract
		tar -xvf "$RESTORE_DIR/$TYPE.ext4.tar"

		echo "status=ok" > "/tmp/aroma/restore_status.prop"

	else

		echo "status=fail" > "/tmp/aroma/restore_status.prop"

	fi

fi
